@@ -12,7 +12,7 @@ from .steps import StepResult
 
 class RunResult:
     _run_plan: dict[Stage, set[Project]]
-    _results: list[StepResult] = []
+    _results: list[StepResult]
     _run_properties: RunProperties
     _exception: Optional[Exception]
 
@@ -22,6 +22,7 @@ class RunResult:
         self._run_properties = run_properties
         self._run_plan = run_plan
         self._exception = None
+        self._results = []
 
     @property
     def status_line(self) -> str:
@@ -34,6 +35,24 @@ class RunResult:
 
         return '❌ Failed'
 
+    @property
+    def progress_fraction(self) -> float:
+        unfinished = 0
+        finished = 0
+        for stage, projects in self.run_plan.items():
+            finished_project_names = set(map(lambda r: r.project.name, self.results_for_stage(stage)))
+            for project in projects:
+                if project.name in finished_project_names:
+                    finished += 1
+                else:
+                    unfinished += 1
+
+        total = unfinished + finished
+        if total == 0:
+            return 0.0
+
+        return 1.0 - (unfinished / total)
+
     @property
     def exception(self) -> Optional[Exception]:
         return self._exception
@@ -64,12 +83,7 @@ class RunResult:
 
     @property
     def is_finished(self):
-        for stage, projects in self.run_plan.items():
-            finished_project_names = set(map(lambda r: r.project.name, self.results_for_stage(stage)))
-            for project in projects:
-                if project.name not in finished_project_names:
-                    return False
-        return True
+        return self.progress_fraction == 1.0
 
     @property
     def is_in_progress(self):
